#!/bin/bash
###############################################################################
# This script will update the scini modules cache for all kernels
# available on this machine.
###############################################################################

# Scream when substituting uninitialized vars
set -u

# Debug flag (set if non-empty)
DEBUGGING=

###############################################################################
installed_ver() {
    # Check for version file, and if doesn't exist, use hardcoded from
    # last scaleio update.
    if [ -f /opt/emc/scaleio/sdc/bin/bin/.installed ]; then
        cat /opt/emc/scaleio/sdc/bin/bin/.installed
    else
        echo 2.0.664.0
    fi
}

###############################################################################
print_sep_line()
{
  cat << EOF
###############################################################################
EOF
}

###############################################################################

ini_bindir=/bin/emc/scaleio
ini_module=scini.ko
ini_ver=$(installed_ver)

print_sep_line

echo "Updating scini cache for all visible kernels on this machine"

read -a kernels_list <<< $(ls -1 /lib/modules)

for kernel_name in ${kernels_list[@]} ; do
    echo "Will attempt fetch module for kernel $kernel_name... "

    $ini_bindir/scini_sync.sh -c $ini_bindir/scini_sync.conf \
      retrieve Ubuntu/$ini_ver/$kernel_name

    if [ $? -eq 0 ]; then
        echo " - Ok."
    else
        echo " - Failed."
    fi
done

print_sep_line

